pub fn load_json(path: &str) -> Result<ErrorCodeMap>Expand description
Load S3 error codes from a JSON file.
Errors
Returns an error if the file cannot be read or parsed.
pub fn load_json(path: &str) -> Result<ErrorCodeMap>Load S3 error codes from a JSON file.
Returns an error if the file cannot be read or parsed.